==> adoptr_1.0.0.tar.gz: adoptr/README.md <==
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2616951.svg)](https://doi.org/10.5281/zenodo.2616951)

[![R-CMD-check](https://github.com/kkmann/adoptr/actions/workflows/check-package.yaml/badge.svg)](https://github.com/kkmann/adoptr/actions/workflows/check-package.yaml)
[![Codecov test coverage](https://codecov.io/gh/kkmann/adoptr/branch/master/graph/badge.svg)](https://codecov.io/gh/kkmann/adoptr?branch=master)
[![CRAN status](https://www.r-pkg.org/badges/version/adoptr)](https://cran.r-project.org/package=adoptr)
[![](http://cranlogs.r-pkg.org/badges/last-month/adoptr?color=green)](https://cran.r-project.org/package=adoptr)
[![](http://cranlogs.r-pkg.org/badges/grand-total/adoptr?color=green)](https://cran.r-project.org/package=adoptr)


# adoptr <a href='https://github.com/kkmann/adoptr'><img src='man/figures/logo.png' align="right" height="139" /></a>


Adaptive optimal two-stage designs for clinical trials with one or two arms. 
For details on the core theoretical background, see:

> Pilz M, Kunzmann K, Herrmann C, Rauch G, Kieser M. A variational approach to
optimal two-stage designs. *Statistics in Medicine*. 2019;38(21):4159–4171.
https://doi.org/10.1002/sim.8291



## Installation

Install the latest CRAN release via

```r
install.packages("adoptr")
```

and the development version directly from [GitHub](https://github.com/) with:

```r
devtools::install_github("kkmann/adoptr")
```



## Documentation

The documentation is hosted at https://kkmann.github.io/adoptr.



## Validation Report

We provide an extensive validation report for **adoptr** which is implemented 
using the **bookdown** package.
The sources are available at https://github.com/kkmann/adoptr-validation-report and
the last build version is hosted at https://kkmann.github.io/adoptr-validation-report.

==> adoptr_1.0.1.tar.gz: adoptr/README.md <==
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2616951.svg)](https://doi.org/10.5281/zenodo.2616951)

[![R-CMD-check](https://github.com/optad/adoptr/actions/workflows/check-package.yaml/badge.svg)](https://github.com/optad/adoptr/actions/workflows/check-package.yaml)
[![Codecov test coverage](https://codecov.io/gh/optad/adoptr/branch/main/graph/badge.svg)](https://app.codecov.io/gh/optad/adoptr?branch=main)
[![CRAN status](https://www.r-pkg.org/badges/version/adoptr)](https://cran.r-project.org/package=adoptr)
[![](http://cranlogs.r-pkg.org/badges/last-month/adoptr?color=green)](https://cran.r-project.org/package=adoptr)
[![](http://cranlogs.r-pkg.org/badges/grand-total/adoptr?color=green)](https://cran.r-project.org/package=adoptr)


# adoptr <a href='https://github.com/optad/adoptr'><img src='man/figures/logo.png' align="right" height="139" /></a>


Adaptive optimal two-stage designs for clinical trials with one or two arms. 
For details on the core theoretical background, see:

> Pilz M, Kunzmann K, Herrmann C, Rauch G, Kieser M. A variational approach to
optimal two-stage designs. *Statistics in Medicine*. 2019;38(21):4159–4171.
https://doi.org/10.1002/sim.8291



## Installation

Install the latest CRAN release via

```r
install.packages("adoptr")
```

and the development version directly from [GitHub](https://github.com/) with:

```r
devtools::install_github("optad/adoptr")
```



## Documentation

The documentation is hosted at https://optad.github.io/adoptr.



## Validation Report

We provide an extensive validation report for **adoptr** which is implemented 
using the **bookdown** package.
The sources are available at https://github.com/kkmann/adoptr-validation-report and
the last build version is hosted at https://kkmann.github.io/adoptr-validation-report.
